@@ -27,14 +27,14 @@ class InspectMode:
   def __init__(self, files: List[str]) -> None:
     self._files = files
 
-  def invoke(self) -> int:
+  async def invoke(self) -> int:
     assert self._files
     from trueseeing.core.context import Context
 
     f = self._files[0]
-    with Context(f) as context:
+    with Context(f, []) as context:
       ui.info(f"inspection mode; analyzing {f}")
-      context.analyze()
+      await context.analyze()
       ui.info("analyzed, context in 'context'")
       from IPython import embed
       embed()
